summaryrefslogtreecommitdiffstats
path: root/agent/polkitqt1-agent-session.h
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2021-10-31 00:13:21 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2021-10-31 00:14:22 +0900
commite8933e99b4600d91e9eab7d1ad3a2d35813028a9 (patch)
treeb2899fd1ef651a1bff56918ace94625a4bc14aa0 /agent/polkitqt1-agent-session.h
parente8494e60efeb94c67c813d1c1c038031915e8c17 (diff)
downloadpolkit-tqt-e8933e99b4600d91e9eab7d1ad3a2d35813028a9.tar.gz
polkit-tqt-e8933e99b4600d91e9eab7d1ad3a2d35813028a9.zip
More Qt->TQt conversion and some clean up.
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'agent/polkitqt1-agent-session.h')
-rw-r--r--agent/polkitqt1-agent-session.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/agent/polkitqt1-agent-session.h b/agent/polkitqt1-agent-session.h
index f4f4ff49c..a40b5b867 100644
--- a/agent/polkitqt1-agent-session.h
+++ b/agent/polkitqt1-agent-session.h
@@ -1,5 +1,5 @@
/*
- * This file is part of the PolKit1-qt project
+ * This file is part of the PolKit1-tqt project
* Copyright (C) 2009 Radek Novacek <rnovacek@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,11 +18,11 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef POLKITQT1_AGENT_SESSION_H
-#define POLKITQT1_AGENT_SESSION_H
+#ifndef POLKITTQT1_AGENT_SESSION_H
+#define POLKITTQT1_AGENT_SESSION_H
#include <TQtCore/TQObject>
-#include "polkitqt1-identity.h"
+#include "polkittqt1-identity.h"
typedef struct _GSimpleAsyncResult GSimpleAsyncResult;
typedef struct _PolkitAgentSession PolkitAgentSession;
@@ -45,7 +45,7 @@ namespace Agent
* \internal
* \brief Encapsulation of GSimpleAsyncResult to TQObject class
*/
-class POLKITQT1_EXPORT AsyncResult
+class POLKITTQT1_EXPORT AsyncResult
{
public:
explicit AsyncResult(GSimpleAsyncResult *result);
@@ -70,14 +70,14 @@ private:
};
/**
- * \class Session polkitqt1-agent-session.h Session
+ * \class Session polkittqt1-agent-session.h Session
* \author Radek Novacek <rnovacek@redhat.com>
*
* This class is interface for interacting with native
* authentication system for obtaining authorizations.
*
*/
-class POLKITQT1_EXPORT Session : public TQObject
+class POLKITTQT1_EXPORT Session : public TQObject
{
Q_OBJECT
TQ_DISABLE_COPY(Session)
@@ -137,7 +137,7 @@ public:
Q_SIGNALS:
/**
* This signal will be emitted when the authentication
* polkitqt1-agent-session.has been completed or cancelled.
*
* \param gainedAuthorization \c True if authorization was successfully obtained.
*/
@@ -137,7 +137,7 @@ public:
/**
* This signal will be emitted when the authentication
- * polkitqt1-agent-session.has been completed or cancelled.
+ * polkittqt1-agent-session.has been completed or cancelled.
*
* \param gainedAuthorization \c True if authorization was successfully obtained.